% TEST_VECTTOCOL Unitary tests for the vecttocol sub-function
% Note:
%   Matlab package functionality is not very test-framework friendly.
%   Either the whole package has to be imported in EVERY SINGLE TEST or the
%   functions must be called as <package>.function() everytime.
%   The second option is preferred for the tests as it has the smaller scope.
%
% -----
% (c) Copyright 2022 University of Liege
% Author: Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% Apache 2.0 License
% https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox

% --------------------------------------------------------------------------------------------------

%% Main test function

function tests = test_vecttocol

    tests = functiontests(localfunctions);

end

%% Setup and teardown

function setupOnce(testCase)

    addpath('../.'); % Add repository to Matlab Path
    addpath('./test_utils'); % Add utils to Matlab Path

    % Set random number generator settings
    testCase.TestData.currentRNG = rng;

end

function teardownOnce(testCase)

    rmpath('../.'); % Remove repository from Matlab Path
    rmpath('./test_utils'); % Remove utils from Matlab Path

    % Restore the random number generator settings
    s = testCase.TestData.currentRNG;
    rng(s);

end

function teardown(~)

    close all; % Close all figures that would have been openend

end

%% Test for correct output

function test_scalar(testCase)
    % If input is scalar, output should be same scalar

    scal = 0;

    verifyEqual(testCase, af_tools.utils.vecttocol(scal), scal);

end

function test_rowVector(testCase)
    % If input is a row vector, output should be its transpose (column vector)

    rowVect = 1:10;

    verifyEqual(testCase, af_tools.utils.vecttocol(rowVect), rowVect');

end

function test_colVect(testCase)
    % If input is a column vector, output should be the same vector

    colVect = (1:10)';

    verifyEqual(testCase, af_tools.utils.vecttocol(colVect), colVect);

end

function test_array(testCase)
    % If input is an array, output should be the same array

    array = rand(5);

    verifyEqual(testCase, af_tools.utils.vecttocol(array), array);

end
